#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-03.12
#
# Check Point Identity Awareness AD Query metrics plugin
# checkpoint_ia_query
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    perfometer_info,
    indexed_color,
)

_MAX_DCS = 48  # max colors ;-)

metric_info['checkpoint_ia_adquery_events_sum'] = {
    'title': _('Events summary'),
    'unit': '1/s',
    'color': '26/a',
}

for i in range(1, _MAX_DCS):
    # generate different colors for each DC.
    # unfortunately there are only 24 colors on our
    # color wheel, times two for two shades each, we
    # can only draw 48 differently colored graphs
    metric_info[f'checkpoint_ia_adquery_dc_{i}'] = {
        'title': _(f'DC{i:02d} Events'),
        'unit': '1/s',
        'color': indexed_color(i, _MAX_DCS),
    }

dc_metric = ([(f'checkpoint_ia_adquery_dc_{num:d}', 'stack') for num in range(_MAX_DCS, 0, -1)])
dc_metric.insert(0, ('checkpoint_ia_adquery_events_sum', 'line'))

graph_info['checkpoint_ia_adquery_dc'] = {
    'title': _('Check Point Identity Awareness AD queries'),
    'metrics': dc_metric,
    'range': (0, None),
    'optional_metrics': [f'checkpoint_ia_adquery_dc_{num:d}' for num in range(0, _MAX_DCS + 1)]
}

perfometer_info.append({
    'type': 'linear',
    'segments': [
        'checkpoint_ia_adquery_events_sum',
    ],
    'total': 100,
})
